@@ -2,50 +2,50 @@ use strict;
 use warnings;
 package Rubric::WebApp;
 # ABSTRACT: the web interface to Rubric
-$Rubric::WebApp::VERSION = '0.155';
-# =head1 SYNOPSIS
-#
-#  use strict;
-#  use warnings;
-#  use Rubric::WebApp;
-#  Rubric::WebApp->new->run();
-#
-# It's a CGI::Application!
-#
-# =head1 DESCRIPTION
-#
-# Rubric::WebApp provides a CGI-based interface to Rubric data.  It's built on
-# top of CGI::Application, which does most of the boring work.  This module's
-# code sets up the dispatch tables and implements the responses to various
-# queries.
-#
-# =head1 REQUESTS DISPATCH
-#
-# Requests are I<mostly> path-based, though some involve form submission.  The
-# basic dispatch table looks something like this:
-#
-#  request      | description                               | method called
-#  -------------+-------------------------------------------+--------------
-#  /login       | log in to a user account                  | login
-#  /logout      | log out                                   | logout
-#  /preferences | view or change account settings           | preferences
-#  /newuser     | create a new user account                 | newuser
-#  /verify      | verify a pending user account             | verify
-#  /link        | view the details of entries for a link    | link
-#  /post        | post or edit an entry (must be logged in) | post
-#  /edit        | edit an entry (must be logged in)         | edit
-#  /delete      | delete an entry (must be logged in)       | delete
-#  /entry/ENTRY | find and display the identified entry     | entry
-#  /entries/Q   | find and display results for query Q      | entries
-#  /~USER/TAGS  | see a user's entries for given tags       | (in flux)
-#  /doc/PAGE    | view the named page in the documentation  | doc
-#  /style/PAGE  | get the named style sheet                 | style
-#
-# If the system is private and no user is logged in, the default action is to
-# display a login screen.  If the system is public, or a user is logged in, the
-# default action is to display entries.
-#
-# =cut
+$Rubric::WebApp::VERSION = '0.156';
+#pod =head1 SYNOPSIS
+#pod
+#pod  use strict;
+#pod  use warnings;
+#pod  use Rubric::WebApp;
+#pod  Rubric::WebApp->new->run();
+#pod
+#pod It's a CGI::Application!
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Rubric::WebApp provides a CGI-based interface to Rubric data.  It's built on
+#pod top of CGI::Application, which does most of the boring work.  This module's
+#pod code sets up the dispatch tables and implements the responses to various
+#pod queries.
+#pod
+#pod =head1 REQUESTS DISPATCH
+#pod
+#pod Requests are I<mostly> path-based, though some involve form submission.  The
+#pod basic dispatch table looks something like this:
+#pod
+#pod  request      | description                               | method called
+#pod  -------------+-------------------------------------------+--------------
+#pod  /login       | log in to a user account                  | login
+#pod  /logout      | log out                                   | logout
+#pod  /preferences | view or change account settings           | preferences
+#pod  /newuser     | create a new user account                 | newuser
+#pod  /verify      | verify a pending user account             | verify
+#pod  /link        | view the details of entries for a link    | link
+#pod  /post        | post or edit an entry (must be logged in) | post
+#pod  /edit        | edit an entry (must be logged in)         | edit
+#pod  /delete      | delete an entry (must be logged in)       | delete
+#pod  /entry/ENTRY | find and display the identified entry     | entry
+#pod  /entries/Q   | find and display results for query Q      | entries
+#pod  /~USER/TAGS  | see a user's entries for given tags       | (in flux)
+#pod  /doc/PAGE    | view the named page in the documentation  | doc
+#pod  /style/PAGE  | get the named style sheet                 | style
+#pod
+#pod If the system is private and no user is logged in, the default action is to
+#pod display a login screen.  If the system is public, or a user is logged in, the
+#pod default action is to display entries.
+#pod
+#pod =cut
 
 use CGI::Application 3;
 use base qw(CGI::Application);
@@ -68,14 +68,14 @@ use Rubric::WebApp::Session;
 
 use String::Truncate qw(elide);
 
-# =head1 METHODS
-#
-# =head2 redirect($uri, $message)
-#
-# This method simplifies redirection; it redirects to the given URI, printing the
-# given message as the body of the HTTP response.
-#
-# =cut
+#pod =head1 METHODS
+#pod
+#pod =head2 redirect($uri, $message)
+#pod
+#pod This method simplifies redirection; it redirects to the given URI, printing the
+#pod given message as the body of the HTTP response.
+#pod
+#pod =cut
 
 sub redirect {
   my ($self, $uri, $message) = @_;
@@ -85,11 +85,11 @@ sub redirect {
   return $message;
 }
 
-# =head2 redirect_root($message)
-#
-# This is shorthand to redirect to the Rubric's root URI.  It calls C<redirect>.
-#
-# =cut
+#pod =head2 redirect_root($message)
+#pod
+#pod This is shorthand to redirect to the Rubric's root URI.  It calls C<redirect>.
+#pod
+#pod =cut
 
 sub redirect_root {
   my ($self, $message) = @_;
@@ -97,12 +97,12 @@ sub redirect_root {
   return $self->redirect(Rubric::Config->uri_root, $message);
 }
 
-# =head2 cgiapp_init
-#
-# This method is called during CGI::Application's initialization.  It sets up the
-# session configuration.
-#
-# =cut
+#pod =head2 cgiapp_init
+#pod
+#pod This method is called during CGI::Application's initialization.  It sets up the
+#pod session configuration.
+#pod
+#pod =cut
 
 sub cgiapp_init {
   my ($self) = @_;
@@ -115,13 +115,13 @@ sub cgiapp_init {
   $login_class->check_for_login($self);
 }
 
-# =head2 cgiapp_prerun
-#
-# This method is called before the selected runmode.  It checks for a login,
-# checks for updates to result-set paging, and starts processing the request
-# path.
-#
-# =cut
+#pod =head2 cgiapp_prerun
+#pod
+#pod This method is called before the selected runmode.  It checks for a login,
+#pod checks for updates to result-set paging, and starts processing the request
+#pod path.
+#pod
+#pod =cut
 
 sub cgiapp_prerun {
   my ($self) = @_;
@@ -132,26 +132,26 @@ sub cgiapp_prerun {
   $self->param(path => [ @path[ 2 .. $#path ] ]);
 }
 
-# =head2 next_path_part
-#
-# This method shifts the next item off of the request path and returns it.
-#
-# =cut
+#pod =head2 next_path_part
+#pod
+#pod This method shifts the next item off of the request path and returns it.
+#pod
+#pod =cut
 
 sub next_path_part {
   my ($self) = @_;
   shift @{$self->param('path')};
 }
 
-# =head2 check_pager_data
-#
-# This method is called by C<cgiapp_init>, and sets up parameters used for paging
-# entry listings.  The following parameters are used:
-#
-#  per_page - how many items per page; default 25, maximum 100; stored in session;
-#  page     - which page to display; default 1
-#
-# =cut
+#pod =head2 check_pager_data
+#pod
+#pod This method is called by C<cgiapp_init>, and sets up parameters used for paging
+#pod entry listings.  The following parameters are used:
+#pod
+#pod  per_page - how many items per page; default 25, maximum 100; stored in session;
+#pod  page     - which page to display; default 1
+#pod
+#pod =cut
 
 sub check_pager_data {
   my ($self) = @_;
@@ -169,21 +169,21 @@ sub check_pager_data {
   $self->param('page',     int(($self->query->param('page') || 1)));
 }
 
-# =head2 template($template, \%variables)
-#
-# This method is used to render a template with both provided and default
-# variables.
-#
-# Templates are rendered by calling the C<process> method on the template
-# renderer, which is retrieved by calling the C<renderer> method on the WebApp.
-#
-# The following variables are passed by default:
-#
-#  current_user - the currently logged-in user (a Rubric::User object)
-#  per_page     - entries per page (see check_pager_data)
-#  page         - which page (see check_pager_data)
-#
-# =cut
+#pod =head2 template($template, \%variables)
+#pod
+#pod This method is used to render a template with both provided and default
+#pod variables.
+#pod
+#pod Templates are rendered by calling the C<process> method on the template
+#pod renderer, which is retrieved by calling the C<renderer> method on the WebApp.
+#pod
+#pod The following variables are passed by default:
+#pod
+#pod  current_user - the currently logged-in user (a Rubric::User object)
+#pod  per_page     - entries per page (see check_pager_data)
+#pod  page         - which page (see check_pager_data)
+#pod
+#pod =cut
 
 sub template {
   my ($self, $template, $stash) = @_;
@@ -202,12 +202,12 @@ sub template {
   return $output;
 }
 
-# =head2 setup
-#
-# This method, called by CGI::Application's initialization process, sets up
-# the dispatch table for requests, as described above.
-#
-# =cut
+#pod =head2 setup
+#pod
+#pod This method, called by CGI::Application's initialization process, sets up
+#pod the dispatch table for requests, as described above.
+#pod
+#pod =cut
 
 sub setup {
   my ($self) = @_;
@@ -248,12 +248,12 @@ sub _entries_shortcut {
   $self->entries;
 }
 
-# =head2 entries
-#
-# This passes off responsibility to the class named in the C<entries_query_class>
-# configuration option.  This option defaults to Rubric::WebApp::Entries.
-#
-# =cut
+#pod =head2 entries
+#pod
+#pod This passes off responsibility to the class named in the C<entries_query_class>
+#pod configuration option.  This option defaults to Rubric::WebApp::Entries.
+#pod
+#pod =cut
 
 sub entries {
   my ($self) = @_;
@@ -265,11 +265,11 @@ sub entries {
   $entries_class->entries($self);
 }
 
-# =head2 entry
-#
-# This displays the single requested entry.
-#
-# =cut
+#pod =head2 entry
+#pod
+#pod This displays the single requested entry.
+#pod
+#pod =cut
 
 sub entry {
   my ($self) = @_;
@@ -292,12 +292,12 @@ sub entry {
   });
 }
 
-# =head2 get_entry
-#
-# This method gets the next part of the path, assumes it to be a Rubric::Entry
-# id, and puts the corresponding entry in the "entry" parameter.
-#
-# =cut
+#pod =head2 get_entry
+#pod
+#pod This method gets the next part of the path, assumes it to be a Rubric::Entry
+#pod id, and puts the corresponding entry in the "entry" parameter.
+#pod
+#pod =cut
 
 sub get_entry {
   my ($self) = @_;
@@ -306,12 +306,12 @@ sub get_entry {
   $self->param(entry => $entry);
 }
 
-# =head2 link
-#
-# This runmode displays entries that point to a given link, identified either by
-# URI or MD5 sum.
-#
-# =cut
+#pod =head2 link
+#pod
+#pod This runmode displays entries that point to a given link, identified either by
+#pod URI or MD5 sum.
+#pod
+#pod =cut
 
 sub link {
   my ($self) = @_;
@@ -319,13 +319,13 @@ sub link {
   $self->display_entries;
 }
 
-# =head2 get_link
-#
-# This method look for a C<uri> or, failing that, C<url> query parameter.  If
-# found, it finds a Rubric::Link for that URI and puts it in the "link"
-# parameter.
-#
-# =cut
+#pod =head2 get_link
+#pod
+#pod This method look for a C<uri> or, failing that, C<url> query parameter.  If
+#pod found, it finds a Rubric::Link for that URI and puts it in the "link"
+#pod parameter.
+#pod
+#pod =cut
 
 sub get_link {
   my ($self) = @_;
@@ -340,9 +340,9 @@ sub get_link {
   $self->param('link', $link);
 }
 
-# =head2 tag_cloud
-#
-# =cut
+#pod =head2 tag_cloud
+#pod
+#pod =cut
 
 sub tag_cloud {
   my ($self, $options) = @_;
@@ -367,9 +367,9 @@ sub tag_cloud {
 
 }
 
-# =head2 calendar
-#
-# =cut
+#pod =head2 calendar
+#pod
+#pod =cut
 
 sub calendar {
   my ($self, $options) = @_;
@@ -473,12 +473,12 @@ sub calendar {
 
 }
 
-# =head2 login
-#
-# If the user is logged in, this request is immediately redirected to the root of
-# the Rubric site.  Otherwise, a login form is provided.
-#
-# =cut
+#pod =head2 login
+#pod
+#pod If the user is logged in, this request is immediately redirected to the root of
+#pod the Rubric site.  Otherwise, a login form is provided.
+#pod
+#pod =cut
 
 sub login {
   my ($self) = @_;
@@ -494,6 +494,13 @@ sub login {
     $self->query->param('then_goto', $self->query->self_url);
   }
 
+  if (Rubric::Config->secure_login) {
+    if ($self->query->env->{'psgi.url_scheme'} ne 'https') {
+      my $goto = Rubric::WebApp::URI->login;
+      return $self->redirect($goto, "Logged in...");
+    }
+  }
+
   $self->template('login' => {
     note      => $note,
     then_goto => scalar $self->query->param('then_goto'),
@@ -502,12 +509,12 @@ sub login {
   });
 }
 
-# =head2 logout
-#
-# This run mode unsets the "current_user" parameter in the session and the WebApp
-# object, then redirects the user to the root of the Rubric site.
-#
-# =cut
+#pod =head2 logout
+#pod
+#pod This run mode unsets the "current_user" parameter in the session and the WebApp
+#pod object, then redirects the user to the root of the Rubric site.
+#pod
+#pod =cut
 
 sub logout {
   my ($self) = @_;
@@ -517,12 +524,12 @@ sub logout {
   return $self->redirect_root("Logged out...");
 }
 
-# =head2 reset_password
-#
-# This run mode allows a user to request that his password be reset and emailled
-# to him.
-#
-# =cut
+#pod =head2 reset_password
+#pod
+#pod This run mode allows a user to request that his password be reset and emailled
+#pod to him.
+#pod
+#pod =cut
 
 sub reset_password {
   my ($self) = @_;
@@ -543,11 +550,11 @@ sub reset_password {
 
 }
 
-# =head2 setup_reset_code
-#
-# This routine gets a reset code for the user and emails it to him.
-#
-# =cut
+#pod =head2 setup_reset_code
+#pod
+#pod This routine gets a reset code for the user and emails it to him.
+#pod
+#pod =cut
 
 sub setup_reset_code {
   my ($self, $user) = @_;
@@ -558,12 +565,12 @@ sub setup_reset_code {
   $self->template("reset_sent");
 }
 
-# =head2 preferences
-#
-# This method displays account information for the current user.  Some account
-# settings may be changed.
-#
-# =cut
+#pod =head2 preferences
+#pod
+#pod This method displays account information for the current user.  Some account
+#pod settings may be changed.
+#pod
+#pod =cut
 
 sub preferences {
   my ($self) = @_;
@@ -580,12 +587,12 @@ sub preferences {
   $self->update_user(\%prefs);
 }
 
-# =head2 update_user(\%prefs)
-#
-# This method will update the current user object with the changes in C<%prefs>,
-# which is passed by the C<preferences> method.
-#
-# =cut
+#pod =head2 update_user(\%prefs)
+#pod
+#pod This method will update the current user object with the changes in C<%prefs>,
+#pod which is passed by the C<preferences> method.
+#pod
+#pod =cut
 
 sub update_user {
   my ($self, $prefs) = @_;
@@ -607,40 +614,40 @@ sub _get_prefs_form {
   return %form;
 }
 
-# =head2 validate_prefs(\%prefs)
-#
-# Given a set of preference updates from a form submission, this method validates
-# them and returns a description of the validation results.  This method will
-# probably be redesigned (possibly with Data::FormValidator) in the future.
-# Don't count on its interface.
-#
-# =cut
+#pod =head2 validate_prefs(\%prefs)
+#pod
+#pod Given a set of preference updates from a form submission, this method validates
+#pod them and returns a description of the validation results.  This method will
+#pod probably be redesigned (possibly with Data::FormValidator) in the future.
+#pod Don't count on its interface.
+#pod
+#pod =cut
 
-# =begin future
-#
-# sub validate_prefs {
-#   my ($self, $prefs) = @_;
-#   require Data::FormValidator;
-#
-#   my $profile = {
-#     required     => [qw(password)],
-#     optional     => [qw(password_1 password_2 email)],
-#     constraints  => {
-#       email => 'email',
-#       password_1 => {
-#         params     => [qw(password_1 password_2)],
-#         constraint => sub { $_[0] eq $_[1] },
-#       }
-#     },
-#     dependency_groups => { new_password => [qw(password_1 password_2)] }
-#   };
-#
-#   my $results = Data::FormValidator->check($prefs, $profile);
-# }
-#
-# =end future
-#
-# =cut
+#pod =begin future
+#pod
+#pod sub validate_prefs {
+#pod   my ($self, $prefs) = @_;
+#pod   require Data::FormValidator;
+#pod
+#pod   my $profile = {
+#pod     required     => [qw(password)],
+#pod     optional     => [qw(password_1 password_2 email)],
+#pod     constraints  => {
+#pod       email => 'email',
+#pod       password_1 => {
+#pod         params     => [qw(password_1 password_2)],
+#pod         constraint => sub { $_[0] eq $_[1] },
+#pod       }
+#pod     },
+#pod     dependency_groups => { new_password => [qw(password_1 password_2)] }
+#pod   };
+#pod
+#pod   my $results = Data::FormValidator->check($prefs, $profile);
+#pod }
+#pod
+#pod =end future
+#pod
+#pod =cut
 
 sub validate_prefs {
   my ($self, $prefs) = @_;
@@ -673,15 +680,15 @@ sub validate_prefs {
   return %errors;
 }
 
-# =head2 newuser
-#
-# If the proper form information is present, this runmode creates a new user
-# account.  If not, it presents a form.
-#
-# If a user is already logged in, the user is redirected to the root of the
-# Rubric.
-#
-# =cut
+#pod =head2 newuser
+#pod
+#pod If the proper form information is present, this runmode creates a new user
+#pod account.  If not, it presents a form.
+#pod
+#pod If a user is already logged in, the user is redirected to the root of the
+#pod Rubric.
+#pod
+#pod =cut
 
 sub newuser {
   my ($self) = @_;
@@ -704,14 +711,14 @@ sub newuser {
   }
 }
 
-# =head2 validate_newuser_form(\%newuser)
-#
-# Given a set of user data from a form submission, this method validates them and
-# returns a description of the validation results.  This method will probably be
-# redesigned (possibly with Data::FormValidator) in the future.  Don't count on
-# its interface.
-#
-# =cut
+#pod =head2 validate_newuser_form(\%newuser)
+#pod
+#pod Given a set of user data from a form submission, this method validates them and
+#pod returns a description of the validation results.  This method will probably be
+#pod redesigned (possibly with Data::FormValidator) in the future.  Don't count on
+#pod its interface.
+#pod
+#pod =cut
 
 sub validate_newuser_form {
   my ($self, $newuser) = @_;
@@ -743,12 +750,12 @@ sub validate_newuser_form {
   return %errors;
 }
 
-# =head2 create_newuser(\%newuser)
-#
-# This method creates a new user account from the given description.  It sends
-# the user a validation email (if needed) and displays an account creation page.
-#
-# =cut
+#pod =head2 create_newuser(\%newuser)
+#pod
+#pod This method creates a new user account from the given description.  It sends
+#pod the user a validation email (if needed) and displays an account creation page.
+#pod
+#pod =cut
 
 sub create_newuser {
   my ($self, %newuser) = @_;
@@ -769,11 +776,11 @@ sub create_newuser {
   $self->template("account_created");
 }
 
-# =head2 send_reset_email_to($user)
-#
-# This method sends an email to the given user with a URI to reset his password.
-#
-# =cut
+#pod =head2 send_reset_email_to($user)
+#pod
+#pod This method sends an email to the given user with a URI to reset his password.
+#pod
+#pod =cut
 
 sub send_reset_email_to {
   my ($self, $user) = @_;
@@ -788,11 +795,11 @@ sub send_reset_email_to {
   sendmail($message);
 }
 
-# =head2 send_verification_email_to($user)
-#
-# This method sends a verification email to the given user.
-#
-# =cut
+#pod =head2 send_verification_email_to($user)
+#pod
+#pod This method sends a verification email to the given user.
+#pod
+#pod =cut
 
 sub send_verification_email_to {
   my ($self, $user) = @_;
@@ -807,12 +814,12 @@ sub send_verification_email_to {
   sendmail($message);
 }
 
-# =head2 verify
-#
-# This runmode attempts to verify a user account.  It expects a request to be
-# in the form: C< /verify/username/verification_code >
-#
-# =cut
+#pod =head2 verify
+#pod
+#pod This runmode attempts to verify a user account.  It expects a request to be
+#pod in the form: C< /verify/username/verification_code >
+#pod
+#pod =cut
 
 sub verify {
   my ($self) = @_;
@@ -830,12 +837,12 @@ sub verify {
                               : $self->redirect_root("BAD USER NO VALIDATION");
 }
 
-# =head2 get_reset_code
-#
-# This gets the next part of the path and puts it in the C<reset_code>
-# parameter.
-#
-# =cut
+#pod =head2 get_reset_code
+#pod
+#pod This gets the next part of the path and puts it in the C<reset_code>
+#pod parameter.
+#pod
+#pod =cut
 
 sub get_reset_code {
   my ($self) = @_;
@@ -843,12 +850,12 @@ sub get_reset_code {
   $self->param(reset_code => $self->next_path_part);
 }
 
-# =head2 get_verification_code
-#
-# This gets the next part of the path and puts it in the C<verification_code>
-# parameter.
-#
-# =cut
+#pod =head2 get_verification_code
+#pod
+#pod This gets the next part of the path and puts it in the C<verification_code>
+#pod parameter.
+#pod
+#pod =cut
 
 sub get_verification_code {
   my ($self) = @_;
@@ -856,11 +863,11 @@ sub get_verification_code {
   $self->param(verification_code => $self->next_path_part);
 }
 
-# =head2 get_user
-#
-# This gets the next part of the path and puts it in the C<user> parameter.
-#
-# =cut
+#pod =head2 get_user
+#pod
+#pod This gets the next part of the path and puts it in the C<user> parameter.
+#pod
+#pod =cut
 
 sub get_user {
   my ($self) = @_;
@@ -868,13 +875,13 @@ sub get_user {
   $self->param(user => Rubric::User->retrieve($self->next_path_part) || '');
 }
 
-# =head2 display_entries
-#
-# This method searches (with Rubric::Entry) for entries matching the requested
-# user and tags.  It pages the result (with C<page_entries>) and renders the
-# resulting page with C<render_entries>.
-#
-# =cut
+#pod =head2 display_entries
+#pod
+#pod This method searches (with Rubric::Entry) for entries matching the requested
+#pod user and tags.  It pages the result (with C<page_entries>) and renders the
+#pod resulting page with C<render_entries>.
+#pod
+#pod =cut
 
 sub display_entries {
   my ($self) = @_;
@@ -898,17 +905,17 @@ sub display_entries {
   $self->page_entries($entries)->render_entries;
 }
 
-# =head2 page_entries($iterator)
-#
-# Given a Class::DBI::Iterator, this method sets up parameters describing the
-# current page.  Most importantly, it retrieves an Iterator for the slice of
-# entries representing the current page.  The following parameters are set:
-#
-#  entries - a Class::DBI::Iterator for the current page's entries
-#  count   - the number of entries in the entire set
-#  pages   - the number of pages the set spans
-#
-# =cut
+#pod =head2 page_entries($iterator)
+#pod
+#pod Given a Class::DBI::Iterator, this method sets up parameters describing the
+#pod current page.  Most importantly, it retrieves an Iterator for the slice of
+#pod entries representing the current page.  The following parameters are set:
+#pod
+#pod  entries - a Class::DBI::Iterator for the current page's entries
+#pod  count   - the number of entries in the entire set
+#pod  pages   - the number of pages the set spans
+#pod
+#pod =cut
 
 sub page_entries {
   my ($self, $iterator) = @_;
@@ -926,12 +933,12 @@ sub page_entries {
   return $self;
 }
 
-# =head2 render_entries
-#
-# This method renders a template to display the set of entries set up by
-# C<page_entries>.
-#
-# =cut
+#pod =head2 render_entries
+#pod
+#pod This method renders a template to display the set of entries set up by
+#pod C<page_entries>.
+#pod
+#pod =cut
 
 sub render_entries {
   my ($self, $options) = @_;
@@ -952,12 +959,12 @@ sub render_entries {
   });
 }
 
-# =head2 edit
-#
-# If the user isn't logged in, it redirects to demand a login.  If he is, it
-# displays a post form, completed with the given entry's data.
-#
-# =cut
+#pod =head2 edit
+#pod
+#pod If the user isn't logged in, it redirects to demand a login.  If he is, it
+#pod displays a post form, completed with the given entry's data.
+#pod
+#pod =cut
 
 sub edit {
   my ($self) = @_;
@@ -973,18 +980,18 @@ sub edit {
   return $self->post_form();
 }
 
-# =head2 post
-#
-# This method wants to be simplified.
-#
-# If the user isn't logged in, it redirects to demand a login.  If he is, it
-# checks whether it can create a new entry.  If so, it tries to.  If not, it
-# displays a form for doing so.  If the user already has an entry for the given
-# URI, the existing entry is passed to the form renderer.
-#
-# If a new entry is created, the user is redirected to his entry listing.
-#
-# =cut
+#pod =head2 post
+#pod
+#pod This method wants to be simplified.
+#pod
+#pod If the user isn't logged in, it redirects to demand a login.  If he is, it
+#pod checks whether it can create a new entry.  If so, it tries to.  If not, it
+#pod displays a form for doing so.  If the user already has an entry for the given
+#pod URI, the existing entry is passed to the form renderer.
+#pod
+#pod If a new entry is created, the user is redirected to his entry listing.
+#pod
+#pod =cut
 
 sub _post_form_contents {
   my ($self) = @_;
@@ -1062,11 +1069,11 @@ sub post {
   $self->redirect( $goto, "Posted..." );
 }
 
-# =head2 post_form
-#
-# This method renders a form for the user to create a new entry.
-#
-# =cut
+#pod =head2 post_form
+#pod
+#pod This method renders a form for the user to create a new entry.
+#pod
+#pod =cut
 
 sub post_form {
   my ($self, $form, $error) = @_;
@@ -1082,16 +1089,16 @@ sub post_form {
   });
 }
 
-# =head2 delete
-#
-# This method wants to be simplified.  It's largely copied from C<post>.
-#
-# If the user isn't logged in, it redirects to demand a login.  If he is, it
-# checks whether the user has an entry for the given URI.  If so, it's deleted.
-#
-# Either way, the user is redirected to his entry listing.
-#
-# =cut
+#pod =head2 delete
+#pod
+#pod This method wants to be simplified.  It's largely copied from C<post>.
+#pod
+#pod If the user isn't logged in, it redirects to demand a login.  If he is, it
+#pod checks whether the user has an entry for the given URI.  If so, it's deleted.
+#pod
+#pod Either way, the user is redirected to his entry listing.
+#pod
+#pod =cut
 
 sub delete {
   my ($self) = @_;
@@ -1112,11 +1119,11 @@ sub delete {
   return $self->redirect( $goto, "Deleted..." );
 }
 
-# =head2 doc
-#
-# This runmode returns a mostly-static document from the template path.
-#
-# =cut
+#pod =head2 doc
+#pod
+#pod This runmode returns a mostly-static document from the template path.
+#pod
+#pod =cut
 
 sub doc {
   my ($self) = @_;
@@ -1128,11 +1135,11 @@ sub doc {
   return $output ? $output : $self->redirect_root("no such document");
 }
 
-# =head2 get_doc
-#
-# This gets the next part of the path and puts it in the C<doc_page> parameter.
-#
-# =cut
+#pod =head2 get_doc
+#pod
+#pod This gets the next part of the path and puts it in the C<doc_page> parameter.
+#pod
+#pod =cut
 
 sub get_doc {
   my ($self) = @_;
@@ -1142,11 +1149,11 @@ sub get_doc {
                                     : ();
 }
 
-# =head2 style
-#
-# This runmode sends the named stylesheet from the CSS path.
-#
-# =cut
+#pod =head2 style
+#pod
+#pod This runmode sends the named stylesheet from the CSS path.
+#pod
+#pod =cut
 
 sub style {
   my ($self) = @_;
@@ -1182,7 +1189,7 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.155
+version 0.156
 
 =head1 SYNOPSIS
 
