@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Rubric::WebApp::Session;
 # ABSTRACT: the Rubric session plugin
-$Rubric::WebApp::Session::VERSION = '0.155';
+$Rubric::WebApp::Session::VERSION = '0.156';
 use CGI::Cookie;
 use Crypt::CBC;
 use JSON 2 ();
@@ -27,16 +27,16 @@ sub import {
   $self->_import({ into => $caller });
 }
 
-# =head1 METHODS
-#
-# These methods are imported into the using class and should be called on an
-# object of that type -- here, a Rubric::WebApp.
-#
-# =head2 session
-#
-# This returns the session, a hashref.
-#
-# =cut
+#pod =head1 METHODS
+#pod
+#pod These methods are imported into the using class and should be called on an
+#pod object of that type -- here, a Rubric::WebApp.
+#pod
+#pod =head2 session
+#pod
+#pod This returns the session, a hashref.
+#pod
+#pod =cut
 
 sub session {
   my ($self) = @_;
@@ -47,11 +47,11 @@ my $COOKIE_NAME   = 'RubricSession';
 
 sub __empty { Rubric::WebApp::Session::Object->new({}) }
 
-# =head2 session_cipherer
-#
-# This returns a Crypt::CBC object for handling ciphering.
-#
-# =cut
+#pod =head2 session_cipherer
+#pod
+#pod This returns a Crypt::CBC object for handling ciphering.
+#pod
+#pod =cut
 
 sub session_cipherer {
   my ($self) = @_;
@@ -63,11 +63,11 @@ sub session_cipherer {
   );
 }
 
-# =head2 get_cookie_payload
-#
-# This gets the cookie and returns the payload as a R::WA::Session::Object.
-#
-# =cut
+#pod =head2 get_cookie_payload
+#pod
+#pod This gets the cookie and returns the payload as a R::WA::Session::Object.
+#pod
+#pod =cut
 
 sub get_cookie_payload {
   my ($self) = @_;
@@ -85,11 +85,11 @@ sub get_cookie_payload {
   my $session = $data ? Rubric::WebApp::Session::Object->new($data) : __empty;
 }
 
-# =head2 set_cookie_payload
-#
-# This method writes the session data back out to a cookie entry.
-#
-# =cut
+#pod =head2 set_cookie_payload
+#pod
+#pod This method writes the session data back out to a cookie entry.
+#pod
+#pod =cut
 
 sub set_cookie_payload {
   my ($self) = @_;
@@ -101,37 +101,39 @@ sub set_cookie_payload {
   };
 
   my $cookie = CGI::Cookie->new(
-    -name    => $COOKIE_NAME,
-    -expires => '+30d',
-    -value   => $cookie_value,
+    -name     => $COOKIE_NAME,
+    -expires  => '+30d',
+    -value    => $cookie_value,
+    -secure   => Rubric::Config->cookie_secure,
+    -httponly => Rubric::Config->cookie_httponly,
   );
 
   $self->header_add(-cookie => [ $cookie ]);
 }
 
-# =head1 SESSION OBJECT METHODS
-#
-# =cut
+#pod =head1 SESSION OBJECT METHODS
+#pod
+#pod =cut
 
 package Rubric::WebApp::Session::Object;
-$Rubric::WebApp::Session::Object::VERSION = '0.155';
-# =head2 new
-#
-# This makes a new session object.  You don't need this.
-#
-# =cut
+$Rubric::WebApp::Session::Object::VERSION = '0.156';
+#pod =head2 new
+#pod
+#pod This makes a new session object.  You don't need this.
+#pod
+#pod =cut
 
 sub new {
   my ($class, $data) = @_;
   bless $data => $class;
 }
 
-# =head2 param
-#
-#   $obj->param('foo');        # get
-#   $obj->param('foo', 'val'); # set
-#
-# =cut
+#pod =head2 param
+#pod
+#pod   $obj->param('foo');        # get
+#pod   $obj->param('foo', 'val'); # set
+#pod
+#pod =cut
 
 sub param {
   my $self = shift;
@@ -148,37 +150,37 @@ sub param {
   die "invalid number of args to session->param";
 }
 
-# =head2 clear
-#
-#   $obj->clear('name');
-#
-# Clear the entry (delete it entirely) from the session.
-#
-# =cut
+#pod =head2 clear
+#pod
+#pod   $obj->clear('name');
+#pod
+#pod Clear the entry (delete it entirely) from the session.
+#pod
+#pod =cut
 
 sub clear {
   my ($self, $param) = @_;
   delete $self->{$param};
 }
 
-# =head2 delete
-#
-#   $session->delete;
-#
-# Removes all data from the session.
-#
-# =cut
+#pod =head2 delete
+#pod
+#pod   $session->delete;
+#pod
+#pod Removes all data from the session.
+#pod
+#pod =cut
 
 sub delete {
   my ($self) = @_;
   %$self = ();
 }
 
-# =head2 as_hash
-#
-# This returns a hashref containing the session data.
-#
-# =cut
+#pod =head2 as_hash
+#pod
+#pod This returns a hashref containing the session data.
+#pod
+#pod =cut
 
 sub as_hash {
   return { %{ $_[0] } };
@@ -198,7 +200,7 @@ Rubric::WebApp::Session - the Rubric session plugin
 
 =head1 VERSION
 
-version 0.155
+version 0.156
 
 =head1 METHODS
 
