@@ -2,31 +2,31 @@ use strict;
 use warnings;
 package Rubric::WebApp::URI;
 # ABSTRACT: URIs for Rubric web requests
-$Rubric::WebApp::URI::VERSION = '0.155';
-# =head1 DESCRIPTION
-#
-# This module provides methods for generating the URIs for Rubric requests.
-#
-# =cut
+$Rubric::WebApp::URI::VERSION = '0.156';
+#pod =head1 DESCRIPTION
+#pod
+#pod This module provides methods for generating the URIs for Rubric requests.
+#pod
+#pod =cut
 
 use Rubric::Config;
 use Scalar::Util ();
 
-# =head1 METHODS
-#
-# =head2 root
-#
-# the URI for the root of the Rubric; taken from uri_root in config
-#
-# =cut
+#pod =head1 METHODS
+#pod
+#pod =head2 root
+#pod
+#pod the URI for the root of the Rubric; taken from uri_root in config
+#pod
+#pod =cut
 
 sub root { Rubric::Config->uri_root }
 
-# =head2 stylesheet
-#
-# the URI for the stylesheet
-#
-# =cut
+#pod =head2 stylesheet
+#pod
+#pod the URI for the stylesheet
+#pod
+#pod =cut
 
 sub stylesheet {
   my $href = Rubric::Config->css_href;
@@ -34,27 +34,31 @@ sub stylesheet {
   return Rubric::Config->uri_root . '/style/rubric.css';
 }
 
-# =head2 logout
-#
-# URI to log out
-#
-# =cut
+#pod =head2 logout
+#pod
+#pod URI to log out
+#pod
+#pod =cut
 
 sub logout { Rubric::Config->uri_root . '/logout' }
 
-# =head2 login
-#
-# URI to form for log in
-#
-# =cut
+#pod =head2 login
+#pod
+#pod URI to form for log in
+#pod
+#pod =cut
 
-sub login { Rubric::Config->uri_root . '/login' }
+sub login {
+  my $uri = Rubric::Config->uri_root . '/login';
+  $uri =~ s/^http:/https:/i if Rubric::Config->secure_login;
+  return $uri;
+}
 
-# =head2 reset_password
-#
-# URI to reset user password
-#
-# =cut
+#pod =head2 reset_password
+#pod
+#pod URI to reset user password
+#pod
+#pod =cut
 
 sub reset_password {
 	my ($class, $arg) = @_;
@@ -65,26 +69,26 @@ sub reset_password {
 	return $uri;
 }
 
-# =head2 newuser
-#
-# URI to form for new user registration form;  returns false if registration is
-# closed.
-#
-# =cut
+#pod =head2 newuser
+#pod
+#pod URI to form for new user registration form;  returns false if registration is
+#pod closed.
+#pod
+#pod =cut
 
 sub newuser {
 	return if Rubric::Config->registration_closed;
 	return Rubric::Config->uri_root . '/newuser';
 }
 
-# =head2 entries(\%arg)
-#
-# URI for entry listing; valid keys for C<%arg>:
-#
-#  user - entries for one user
-#  tags - arrayref of tag names
-#
-# =cut
+#pod =head2 entries(\%arg)
+#pod
+#pod URI for entry listing; valid keys for C<%arg>:
+#pod
+#pod  user - entries for one user
+#pod  tags - arrayref of tag names
+#pod
+#pod =cut
 
 sub entries {
 	my ($class, $arg) = @_;
@@ -106,11 +110,11 @@ sub entries {
 	return $uri;
 }
 
-# =head2 entry($entry)
-#
-# URI to view entry
-#
-# =cut
+#pod =head2 entry($entry)
+#pod
+#pod URI to view entry
+#pod
+#pod =cut
 
 sub entry {
 	my ($class, $entry) = @_;
@@ -119,11 +123,11 @@ sub entry {
 	return Rubric::Config->uri_root . "/entry/" . $entry->id;
 }
 
-# =head2 edit_entry($entry)
-#
-# URI to edit entry
-#
-# =cut
+#pod =head2 edit_entry($entry)
+#pod
+#pod URI to edit entry
+#pod
+#pod =cut
 
 sub edit_entry {
 	my ($class, $entry) = @_;
@@ -132,11 +136,11 @@ sub edit_entry {
 	return Rubric::Config->uri_root . "/edit/" . $entry->id;
 }
 
-# =head2 delete_entry($entry)
-#
-# URI to delete entry
-#
-# =cut
+#pod =head2 delete_entry($entry)
+#pod
+#pod URI to delete entry
+#pod
+#pod =cut
 
 sub delete_entry {
 	my ($class, $entry) = @_;
@@ -145,19 +149,19 @@ sub delete_entry {
 	return Rubric::Config->uri_root . "/delete/" . $entry->id;
 }
 
-# =head2 post_entry
-#
-# URI for new entry form
-#
-# =cut
+#pod =head2 post_entry
+#pod
+#pod URI for new entry form
+#pod
+#pod =cut
 
 sub post_entry { Rubric::Config->uri_root . "/post"; }
 
-# =head2 by_date
-#
-# URI for by_date
-#
-# =cut
+#pod =head2 by_date
+#pod
+#pod URI for by_date
+#pod
+#pod =cut
 
 sub by_date {
 	my ($class) = @_;
@@ -173,42 +177,42 @@ sub by_date {
 
 
 
-# =head2 tag_cloud
-#
-# URI for all tags / tag cloud
-#
-# =cut
+#pod =head2 tag_cloud
+#pod
+#pod URI for all tags / tag cloud
+#pod
+#pod =cut
 
 sub tag_cloud {
 	my ($class) = @_;
 	Rubric::Config->uri_root . "/tag_cloud";
 }
 
-# =head2 preferences
-#
-# URI for preferences form
-#
-# =cut
+#pod =head2 preferences
+#pod
+#pod URI for preferences form
+#pod
+#pod =cut
 
 
 sub preferences { Rubric::Config->uri_root . "/preferences"; }
 
-# =head2 verify_user
-#
-# URI for new entry form
-#
-# =cut
+#pod =head2 verify_user
+#pod
+#pod URI for new entry form
+#pod
+#pod =cut
 
 sub verify_user {
 	my ($class, $user) = @_;
 	Rubric::Config->uri_root . "/verify/$user/" . $user->verification_code;
 }
 
-# =head2 doc($doc_page)
-#
-# URI for documentation page.
-#
-# =cut
+#pod =head2 doc($doc_page)
+#pod
+#pod URI for documentation page.
+#pod
+#pod =cut
 
 sub doc {
 	my ($class, $doc_page) = @_;
@@ -229,7 +233,7 @@ Rubric::WebApp::URI - URIs for Rubric web requests
 
 =head1 VERSION
 
-version 0.155
+version 0.156
 
 =head1 DESCRIPTION
 
